% Iterative Proportional Fitting (IPF) 
%
% Software: Matlab R2009a
%
%
%      MALES
%
% INPUTS:
%     T       : 56x56 adjacency matrix without row names and column names (adjacency_matrix_males.csv)
%     R       : 56x1 all-ones vector of row sums (row_sums.csv)
%     C       : 1x56 all-ones vector of column sums (column_sums.csv)
%     epsilon : precision for convergence (0.001)
%     max_it  : maximum number of iterations (100)
%
%
% OUTPUTS:
%     S:          56x56 normalized adjacency matrix
%     iterations: number of iterations until convergence
%     errors:     (1 x iterations) vector of errors
 
  

T=load('adjacency_matrix_males.csv');
R=load('row_sums.csv');
C=load('column_sums.csv');

epsilon=0.001;
max_it=100;


% iterations
total_error = sum(abs(sum(T,2)-R)) + sum(abs(sum(T,1)-C));
S = T;
count = 1;
errors(count) = total_error;
while (total_error > epsilon & count < max_it)
  
  % scale rows 
  for i=1:56
    S(i,:) = S(i,:) * R(i) / sum(S(i,:));
  end
  
  % scale columns
  for j=1:56
    S(:,j) = S(:,j) * C(j) / sum(S(:,j));
  end
  
  % test errors
  total_error = sum(abs(sum(S,2)-R)) + sum(abs(sum(S,1)-C));
  count = count + 1;
  errors(count) = total_error;
end % while
iterations = count;

% export narmalized adjacency matrix in csv
csvwrite('normalized_adjacency_matrix_males.csv', S);






%      FEMALES
%
% INPUTS:
%     T       : 56x56 adjacency matrix without row names and column names (adjacency_matrix_females.csv)
%     R       : 56x1 all-ones vector of row sums (row_sums.csv)
%     C       : 1x56 all-ones vector of column sums (column_sums.csv)
%     epsilon : precision for convergence (0.001)
%     max_it  : maximum number of iterations (100)
%
%
% OUTPUTS:
%     S:          56x56 normalized adjacency matrix
%     iterations: number of iterations until convergence
%     errors:     (1 x iterations) vector of errors
 
  

T=load('adjacency_matrix_females.csv');
R=load('row_sums.csv');
C=load('column_sums.csv');

epsilon=0.001;
max_it=100;


% iterations
total_error = sum(abs(sum(T,2)-R)) + sum(abs(sum(T,1)-C));
S = T;
count = 1;
errors(count) = total_error;
while (total_error > epsilon & count < max_it)
  
  % scale rows 
  for i=1:56
    S(i,:) = S(i,:) * R(i) / sum(S(i,:));
  end
  
  % scale columns
  for j=1:56
    S(:,j) = S(:,j) * C(j) / sum(S(:,j));
  end
  
  % test errors
  total_error = sum(abs(sum(S,2)-R)) + sum(abs(sum(S,1)-C));
  count = count + 1;
  errors(count) = total_error;
end % while
iterations = count;

% export narmalized adjacency matrix in csv
csvwrite('normalized_adjacency_matrix_females.csv', S);
